.. -*- mode: rst -*-

|PythonVersion|_ |Coveralls|_ |Travis|_ |PyPi|_ |Doc|_

.. |PythonVersion| image:: https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8-blue
.. _PythonVersion: https://img.shields.io/badge/python-3.6%20%7C%203.7%20%7C%203.8-blue

.. |Coveralls| image:: https://coveralls.io/repos/neurospin-deepinsight/consciousnet/badge.svg?branch=master&service=github
.. _Coveralls: https://coveralls.io/github/neurospin/consciousnet

.. |Travis| image:: https://travis-ci.com/neurospin-deepinsight/consciousnet.svg?branch=master
.. _Travis: https://travis-ci.com/neurospin/consciousnet

.. |PyPi| image:: https://badge.fury.io/py/consciousnet.svg
.. _PyPi: https://badge.fury.io/py/consciousnet

.. |Doc| image:: https://readthedocs.org/projects/consciousnet/badge/?version=latest
.. _Doc: https://consciousnet.readthedocs.io/en/latest/?badge=latest


consciousnet: Consciousness Exploration Tools for PyTorch
=========================================================

\:+1: If you are using the code please add a star to the repository :+1:

PyTorch toolbox with consciousness exploration tools.

.. code::

    @article{zbontar2021barlow,
      title={Barlow Twins: Self-Supervised Learning via Redundancy Reduction},
      author={Zbontar, Jure and Jing, Li and Misra, Ishan and LeCun, Yann and Deny, St{\'e}phane},
      journal={arXiv preprint arXiv:2103.03230},
      year={2021}
    }

    @article {zhang2021stvae,
      author = {Zhang, Xiaodi and Maltbie, Eric and Keilholz, Shella},
      title = {Spatiotemporal Trajectories in Resting-state FMRI Revealed by Convolutional Variational Autoencoder},
      year = {2021},
      journal = {bioRxiv}
    }

    @inproceedings{caron2018deep,
      title={Deep Clustering for Unsupervised Learning of Visual Features},
      author={Caron, Mathilde and Bojanowski, Piotr and Joulin, Armand and Douze, Matthijs},
      booktitle={European Conference on Computer Vision},
      year={2018},
    }

    @inproceedings{gregor2018tdvae,
      title={Temporal Difference Variational Auto-Encoder},
      author={Karol Gregor and George Papamakarios and Frederic Besse and Lars Buesing and Theophane Weber},
      booktitle={International Conference on Learning Representations},
      year={2019}
    }



This work is made available by a `community of people
<https://github.com/neurospin-deepinsight/consciousnet/blob/master/AUTHORS.rst>`_, amoung which the
CEA Neurospin BAOBAB laboratory.

.. image:: ./doc/source/_static/carousel/brain-states.jpg
    :width: 400px
    :align: center
    
Important links
===============

- `Official source code repo <https://github.com/neurospin-deepinsight/consciousnet>`_
- HTML stable documentation: WIP
- `HTML documentation <https://consciousnet.readthedocs.io/en/latest>`_
- `Release notes <https://github.com/neurospin-deepinsight/consciousnet/blob/master/CHANGELOG.rst>`_

Where to start
==============

Examples are available in the
`gallery <https://consciousnet.readthedocs.io/en/latest/auto_gallery/gallery.html>`_.
All datasets are described in the
`API documentation <https://consciousnet.readthedocs.io/en/latest/generated/documentation.html>`_.

Install
=======

The code has been developed for PyTorch version 1.8.1 and torchvision
version 0.9.1, but should work with newer versions as well.
Make sure you have installed all the package dependencies.
Complete instructions are available `here
<https://consciousnet.readthedocs.io/en/latest/generated/installation.html>`_.


License
=======

This project is under the following
`LICENSE <https://github.com/neurospin-deepinsight/consciousnet/blob/master/LICENSE.rst>`_.

